=begin
 Copyright 2009, AlexM

 THIS SOFTWARE IS PROVIDED "AS IS" AND WITHOUT ANY EXPRESS OR
 IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
 WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.

 Author :          AlexM
 Date Original :   v2.1 2009-06-05
=end

class Sketchup::Image

	def definition
		defins = Sketchup.active_model.definitions
		defins.each do |d| next unless d.image?
			return d if d.instances.include? self
		end
	end#def

	def image_material
		entities = self.definition.entities
		material = entities.at(-1).material
		return material if material
		entities.each{|e| return e.material if e.is_a? Sketchup::Face}
		nil
	end#def

end#def

if Sketchup.version_number > 6000000

module ArchTools

class AT_EditImageMaterial

	def self.run
		model = Sketchup.active_model
		ss = model.selection
		image = ss.first
		return nil unless ss.single_object?
		return nil unless image.is_a? Sketchup::Image
		material = image.image_material
		dmp = if material.materialType == 1
			model.start_operation "Create Image Material"
			mat_color = material.color
			material.color = mat_color
			material.color = nil
			model.commit_operation
			[mat_color.to_a, material.alpha, material.texture.filename, material.texture.width, material.texture.height]
		else
			nil
		end
		old_current_material = model.materials.current
		model.materials.current = material
		Sketchup.send_action 21074
		timer = UI.start_timer(0, true) { Sketchup.undo unless material.texture }
		UI.start_timer(0, false){ model.select_tool self.new(old_current_material, material, dmp, timer)}
	end#def

#---------------------------------------------------------------------------------------------------

	def initialize(old_current_material, material, dmp, timer)
		@old_current_material = old_current_material
		@material = material
		@dmp = dmp
		@timer = timer
		@model = Sketchup.active_model
	end#def

	def exit
		@model.select_tool nil
	end#def

	def deactivate(view)
		UI.stop_timer @timer
		@model.materials.current = @old_current_material
		if @dmp
			if @material.color.to_a == @dmp.at(0) &&
					@material.alpha == @dmp.at(1) &&
					@material.texture.filename == @dmp.at(2)
					@material.texture.width == @dmp.at(3) &&
					@material.texture.height == @dmp.at(4)
				Sketchup.undo
				@model.start_operation "ClearRedo"
				@model.abort_operation
			end
		end
	end#def

	def getMenu(menu)
		item = menu.add_item("Exit"){exit}
		menu.set_validation_proc(item){MF_UNCHECKED}
	end#def

end#class

end#module

#---------------------------------------------------------------------------------------------------
file_name = File.basename(__FILE__)
if not file_loaded?(file_name)
	UI.add_context_menu_handler do |menu|
		if Sketchup.active_model.selection.first.is_a? Sketchup::Image
			menu.add_item("AT - Edit Image Material"){ArchTools::AT_EditImageMaterial.run}
		end
	end
	file_loaded(file_name)
end

end#Sketchup.version_number > 6000000